#! /usr/bin/python3.6

abq_conc_force_load_type = (
    "POINTLOAD",
    "DISTRIBUTEDLOAD",
    "LOADDENSITY",
)

abq_dat_output_var_type = (
    "ABQDATOUTPUTTYPE_NODE",
    "ABQDATOUTPUTTYPE_ELEMENT",
    "ABQDATOUTPUTTYPE_CONTACT",
    "ABQDATOUTPUTTYPE_ENERGY",
)

abq_entity_type = (
    "ABQ_NONE",
    "ABQ_NODE",
    "ABQ_ELEMENT",
)

abq_local_csys_type = (
    "ABQ_CARTESIAN",
    "ABQ_CYLINDRICAL",
    "ABQ_SPHERICAL",
    "ABQ_DEFAULTAXIS",
)

abq_ms_frequency_type = (
    "ABQ_INTERVAL",
    "ABQ_INCREMENT",
)

abq_ms_target_method = (
    "ABQ_BELOW_MIN",
    "ABQ_UNIFORM",
    "ABQ_SET_EQUAL",
)

abq_output_at_sec_pts = (
    "ABQDEFAULTSECPTS",
    "ABQALLSECPTS",
)

abq_output_request_type = (
    "ABQFIELD",
    "ABQHISTORY",
    "ABQDATA",
)

abq_output_variable_type = (
    "ABQPRESELECTEDEFVAR",
    "ABQALLVAR",
)

abq_requested_modes_option = (
    "ABQ_ALL",
    "ABQ_VALUE",
)

abq_restart_option = (
    "ABQ_RESTART_NONE",
    "ABQ_RESTART_EVERYINC",
    "ABQ_RESTART_SPECINC",
    "ABQ_RESTART_NUMINT",
    "ABQ_RESTART_LASTINC",
)

abq_restart_read_option = (
    "ABQ_RESTART_END_OF_STEP",
    "ABQ_RESTART_INTERVAL",
)

abq_restart_read_step_sel_option = (
    "ABQ_STEP_OBJECT",
    "ABQ_STEP_NUMBER",
)

accuracy_type = (
    "ACCURACY_TYPE_DISTANCE",
    "ACCURACY_TYPE_SPEED",
)

adjust_method_type = (
    "NOADJUST",
    "OVERCLOSED",
    "TOLERANCE",
)

auto_time_increment_method = (
    "ABQ_ATI_GLOBAL",
    "ABQ_ATI_ELEMENT_BY_ELEMENT",
)

cat3_d_color_inheritance_mode = (
    "cat3DColorInheritanceModeOff",
    "cat3DColorInheritanceModeOn",
)

cat3_d_xml_geom_representation_type = (
    "cat3DXmlExact",
    "cat3DXmlTessellation",
    "cat3DXmlCompressedTessellation",
    "cat3DXmlDynamicTessellation",
    "cat3DXmlStaticTessellation",
    "cat3DXmlXmlTessellation",
)

cat3_d_xml_ppr_save_config = (
    "cat3DXmlProductAndResourceList",
    "cat3DXmlProductList",
    "cat3DXmlResourceList",
)

cat_algorithm_type = (
    "catSimulatedAnnealing",
    "catGradient",
    "catCAAalgorithm",
    "catLocalForConstraints",
)

cat_analysis_set_search_type = (
    "catAnalysisSetSearchIn",
    "catAnalysisSetSearchOut",
    "catAnalysisSetSearchNeutral",
    "catAnalysisSetSearchAll",
)

cat_analysis_set_type = (
    "catAnalysisSetIn",
    "catAnalysisSetOut",
    "catAnalysisSetNeutral",
)

cat_annotated_view_behavior = (
    "CatAnnotatedViewBehaviorLink",
    "CatAnnotatedViewBehaviorUnlink",
)

cat_annotation_set_type = (
    "catAnnotationSetStandard",
    "catAnnotationSetLight",
    "catAnnotationSetResult",
)

cat_arrange_style = (
    "catArrangeCascade",
    "catArrangeTiledHorizontal",
    "catArrangeTiledVertical",
)

cat_arrangement_area_visu_mode = (
    "CatArrangementAreaVisuModeFlat",
    "CatArrangementAreaVisuModeSolid",
)

cat_arrangement_item_res_visu_mode = (
    "CatArrangementItemReservationVisuModeAxis",
    "CatArrangementItemReservationVisuModeFlat",
    "CatArrangementItemReservationVisuModeSolid",
)

cat_arrangement_route_section = (
    "CatArrangementRouteSectionNone",
    "CatArrangementRouteSectionRectangular",
    "CatArrangementRouteSectionRound",
    "CatArrangementRouteSectionFlatOval",
    "CatArrangementRouteSectionRadiusCorner",
    "CatArrangementRouteSectionDoubleRidge",
)

cat_arrangement_route_visu_mode = (
    "CatArrangementRouteVisuModeCurve",
    "CatArrangementRouteVisuModeFlat",
    "CatArrangementRouteVisuModeSolid",
)

cat_asm_auto_switch_to_design_mode = (
    "catAutoSwitchAvailable",
    "catAutoSwitchUnavailable",
)

cat_asm_constraint_creation_mode = (
    "catUseAnyGeometry",
    "catUsePublishedGeometryChildLevel",
    "catUsePublishedGeometryAnyLevel",
)

cat_asm_extend_move_to_fix_t = (
    "catNeverExtendMoveToFixT",
    "catAskIfExtendMoveToFixT",
    "catAlwaysExtendMoveToFixT",
)

cat_asm_paste_component_mode = (
    "catPasteWithoutCsts",
    "catPasteWithCstOnCopy",
    "catPasteWithCstOnCut",
    "catPasteWithCstOnCopyAndCut",
)

cat_asm_quick_constraint_mode = (
    "catSpecifiedOrder",
    "catVerifiedConstraintFirst",
)

cat_asm_redundancy_mode = (
    "catUnChecked",
    "catChecked",
)

cat_asm_update_mode = (
    "catManualUpdate",
    "catAutomaticUpdate",
)

cat_asm_update_status_compute_mode = (
    "catManualCompute",
    "catAutomaticCompute",
)

cat_axis_orientation_type = (
    "catSamCoordinateSystem_Cartesian",
    "catSamCoordinateSystem_Cylindrical",
    "catSamCoordinateSystem_Spherical",
    "catSamCoordinateSystem_Undefined",
)

cat_axis_system_axis_type = (
    "catAxisSystemAxisSameDirection",
    "catAxisSystemAxisByCoordinates",
    "catAxisSystemAxisOppositeDirection",
)

cat_axis_system_main_type = (
    "catAxisSystemStandard",
    "catAxisSystemAxisRotation",
    "catAxisSystemEulerAngles",
    "catAxisSystemExplicit",
)

cat_axis_system_origin_type = (
    "catAxisSystemOriginByPoint",
    "catAxisSystemOriginByCoordinates",
)

cat_back_face_culling_mode = (
    "CATBackFaceCullingOnSolidFaces",
    "CATBackFaceCullingOnAllFaces",
    "CATBackFaceCullingOnStandAloneFaces",
    "CATBackFaceCullingOnNoFaces",
)

cat_banner_position = (
    "catBannerPositionNone",
    "catBannerPositionBottom",
    "catBannerPositionTop",
    "catBannerPositionLeft",
    "catBannerPositionRight",
)

cat_blanking_mode = (
    "catBlankingInactive",
    "catBlankingActive",
    "catBlankingOnGeom",
)

cat_camera_type = (
    "catCamera2D",
    "catCamera3D",
)

cat_capture_format = (
    "catCaptureFormatCGM",
    "catCaptureFormatEMF",
    "catCaptureFormatTIFF",
    "catCaptureFormatTIFFGreyScale",
    "catCaptureFormatBMP",
    "catCaptureFormatJPEG",
)

cat_chamfer_mode = (
    "catTwoLengthChamfer",
    "catLengthAngleChamfer",
)

cat_chamfer_orientation = (
    "catNoReverseChamfer",
    "catReverseChamfer",
)

cat_chamfer_propagation = (
    "catTangencyChamfer",
    "catMinimalChamfer",
)

cat_circular_pattern_parameters = (
    "catInstancesandAngularSpacing",
    "catCompleteCrown",
    "catUnequalAngularSpacing",
)

cat_clash_computation_type = (
    "catClashComputationTypeBetweenAll",
    "catClashComputationTypeInsideOne",
    "catClashComputationTypeAgainstAll",
    "catClashComputationTypeBetweenTwo",
)

cat_clash_export_type = (
    "CatClashExportTypeXMLResultOnly",
)

cat_clash_import_type = (
    "CatClashImportTypeClashOnly",
    "CatClashImportTypeStructureAndClash",
)

cat_clash_interference_type = (
    "catClashInterferenceTypeContact",
    "catClashInterferenceTypeClearance",
    "catClashInterferenceAuthorizedPenetration",
    "catClashInterferenceCaseRule",
)

cat_clipping_frame_reframe_on_mode = (
    "catOnViewContent",
    "catOnViewBackground",
)

cat_clipping_mode = (
    "catClippingModeClear",
    "catClippingModeNear",
    "catClippingModeFar",
    "catClippingModeNearAndFar",
)

cat_conflict_comparison = (
    "catConflictComparisonNew",
    "catConflictComparisonOld",
    "catConflictComparisonNo",
)

cat_conflict_status = (
    "catConflictStatusNotInspected",
    "catConflictStatusRelevant",
    "catConflictStatusIrrelevant",
    "catConflictStatusSolved",
)

cat_conflict_type = (
    "catConflictTypeClash",
    "catConflictTypeContact",
    "catConflictTypeClearance",
)

cat_constraint_angle_sector = (
    "catCstAngleSector0",
    "catCstAngleSector1",
    "catCstAngleSector2",
    "catCstAngleSector3",
)

cat_constraint_dist_config = (
    "catCstDCUnspec",
    "catCstDCParallel",
    "catCstDCParallelSameOrient",
    "catCstDCParallelOppOrient",
)

cat_constraint_dist_direction = (
    "catCstDistDirectionNone",
    "catCstDistDirection1",
    "catCstDistDirection2",
    "catCstDistDirection3",
)

cat_constraint_mode = (
    "catCstModeDrivingDimension",
    "catCstModeDrivenDimension",
)

cat_constraint_orientation = (
    "catCstOrientSame",
    "catCstOrientOpposite",
    "catCstOrientUndefined",
)

cat_constraint_ref_axis = (
    "catCstRefAxisX",
    "catCstRefAxisY",
    "catCstRefAxisZ",
)

cat_constraint_ref_type = (
    "catCstRefTypeRelative",
    "catCstRefTypeFixInSpace",
)

cat_constraint_side = (
    "catCstSidePositive",
    "catCstSideNegative",
    "catCstSideSameAsValue",
    "catCstSideOppositeToValue",
    "catCstSideUndefined",
)

cat_constraint_status = (
    "catCstStatusOK",
    "catCstStatusKOStronglyNotSatisfied",
    "catCstStatusKOWrongOrientOrSide",
    "catCstStatusKOWrongValue",
    "catCstStatusKOWrongGeomEltType",
    "catCstStatusKOBroken",
)

cat_constraint_type = (
    "catCstTypeReference",
    "catCstTypeDistance",
    "catCstTypeOn",
    "catCstTypeConcentricity",
    "catCstTypeTangency",
    "catCstTypeLength",
    "catCstTypeAngle",
    "catCstTypePlanarAngle",
    "catCstTypeParallelism",
    "catCstTypeAxisParallelism",
    "catCstTypeHorizontality",
    "catCstTypePerpendicularity",
    "catCstTypeAxisPerpendicularity",
    "catCstTypeVerticality",
    "catCstTypeRadius",
    "catCstTypeSymmetry",
    "catCstTypeMidPoint",
    "catCstTypeEquidistance",
    "catCstTypeMajorRadius",
    "catCstTypeMinorRadius",
    "catCstTypeSurfContact",
    "catCstTypeLinContact",
    "catCstTypePoncContact",
    "catCstTypeChamfer",
    "catCstTypeChamferPerpend",
    "catCstTypeAnnulContact",
    "catCstTypeCylinderRadius",
    "catCstTypeStContinuity",
    "catCstTypeStDistance",
    "catCstTypeSdContinuity",
    "catCstTypeSdShape",
)

cat_cs_hole_mode = (
    "catCSModeDepthAngle",
    "catCSModeDepthDiameter",
    "catCSModeAngleDiameter",
)

cat_dedicated_filter_type = (
    "catDisplayInBackground",
    "catMaskInBackground",
)

cat_description_length_type = (
    "ShortText",
    "LongText",
)

cat_dft_weld_finish_symbol = (
    "catFinishWeldingNone",
    "catDftLetterCWelding",
    "catDftLetterFWelding",
    "catDftLetterGWelding",
    "catDftLetterHWelding",
    "catDftLetterMWelding",
    "catDftLetterRWelding",
    "catDftLetterUWelding",
)

cat_dft_welding_tail = (
    "catDftWeldingTailNO",
    "catDftWeldingTailYES",
)

cat_dim_analyse = (
    "catDimOnGenItems",
    "catUnUpdatableDim",
    "catFakeDim",
    "catDrivingDim",
    "catBrokenDim",
    "catTrueDim",
    "catBasic",
    "cat3DDrivableDim",
    "cat3DDrivedDim",
    "catIsolatedDim",
    "catDimOnHideGeom",
    "cat3DFeatureDim",
)

cat_dim_dual_display = (
    "catDualNone",
    "catDualBellow",
    "catDualFractional",
    "catDualSideBySide",
)

cat_dim_fake = (
    "catDimFakeNone",
    "catDimFakeNumValue",
    "catDimFakeText",
)

cat_dim_frame = (
    "catFraNone",
    "catFraCircle",
    "catFraScoredCircle",
    "catFraDiamondShaped",
    "catFraSquare",
    "catFraRectangle",
    "catFraOblong",
    "catFraRightFlag",
    "catFraRightTriangle",
)

cat_dim_framed_element = (
    "catFraValue",
    "catFraValueTol",
    "catFraValueTolText",
)

cat_dim_framed_group = (
    "catFraMain",
    "catFraDual",
    "catFraMainAndDual",
    "catFraBoth",
)

cat_dim_line_graph_rep = (
    "catDimLine1Part",
    "catDimLine2Parts",
    "catDimLineLeader1Part",
    "catDimLineLeader2Part",
)

cat_dim_line_rep = (
    "catDimUndef",
    "catDimHoriz",
    "catDimVert",
    "catDimAuto",
    "catDimUserDefined",
    "catDimTrueDim",
    "catDimParallel",
    "catDimOffset",
)

cat_dim_mode = (
    "catDimClassical",
    "catDimCumulate",
    "catDimHalfDim",
    "catDimChained",
    "catDimStacked",
    "catDimCumulatesystem",
    "catDimHalfDimSystem",
)

cat_dim_orientation = (
    "catHorizontal",
    "catVertical",
    "catParallel",
    "catPerpandicular",
    "catAngle",
)

cat_dim_reference = (
    "catScreen",
    "catView",
    "catDimLine",
)

cat_dim_score = (
    "catDimScoreNone",
    "catDimUnderScored",
    "catDimScored",
    "catCATDrwDimOverScored",
)

cat_dim_symbols = (
    "catDimSymbNone",
    "catDimSymbOpenArrow",
    "catDimSymbClosedArrow",
    "catDimSymbFilledArrow",
    "catDimSymbSymArrow",
    "catDimSymbSlash",
    "catDimSymbCircle",
    "catDimSymbFilledCircle",
    "catDimSymbScoredCircle",
    "catDimSymbCircledCross",
    "catDimSymbTriangle",
    "catDimSymbFilledTriangle",
    "catDimSymbCross",
    "catDimSymbXCross",
)

cat_dim_type = (
    "catDimDistance",
    "catDimDistanceOffset",
    "catDimLength",
    "catDimLengthCurvilinear",
    "catDimAngle",
    "catDimRadius",
    "catDimRadiusTangent",
    "catDimRadiusCylinder",
    "catDimRadiusEdge",
    "catDimDiameter",
    "catDimDiameterTangent",
    "catDimDiameterCylinder",
    "catDimDiameterEdge",
    "catDimDiameterCone",
    "catDimChamfer",
    "catDimSlope",
    "catDimLengthCircular",
    "catDimRadiusFillet",
    "catDimDiameterTorus",
    "catDimRadiusTorus",
    "catDimDistanceMin",
)

cat_distance_computation_type = (
    "catDistanceComputationTypeInsideOne",
    "catDistanceComputationTypeAgainstAll",
    "catDistanceComputationTypeBetweenTwo",
)

cat_distance_measure_type = (
    "catDistanceMeasureTypeMinimum",
    "catDistanceMeasureTypeAlongX",
    "catDistanceMeasureTypeAlongY",
    "catDistanceMeasureTypeAlongZ",
    "catDistanceMeasureTypeBand",
)

cat_dmu_group_preview_hidden_objects_display_mode = (
    "CatDMUGroupPreviewShowHidden",
    "CatDMUGroupPreviewShowHiddenCustom",
)

cat_doc_contextual_priority = (
    "CATDocContextualTechDoc",
    "CATDocContextualUserComp",
)

cat_draft_mode = (
    "catStandardDraftMode",
    "catReflectKeepFaceDraftMode",
    "catReflectKeepEdgeDraftMode",
)

cat_draft_multiselection_mode = (
    "catNoneDraftMultiselectionMode",
    "catDraftMultiselectionByNeutralMode",
)

cat_draft_neutral_propagation_mode = (
    "catNoneDraftNeutralPropagationMode",
    "catSmoothDraftNeutralPropagationMode",
)

cat_drawing_standard = (
    "catANSI",
    "catISO",
    "catJIS",
)

cat_drawing_view_type = (
    "catViewBackground",
    "catViewFront",
    "catViewLeft",
    "catViewRight",
    "catViewTop",
    "catViewBottom",
    "catViewRear",
    "catViewAuxiliary",
    "catViewIsom",
    "catViewSection",
    "catViewSectionCut",
    "catViewDetail",
    "catViewUntyped",
    "catViewMain",
    "catViewPure_Sketch",
    "catViewUnfolded",
)

cat_drw_new_sheet_from = (
    "catDrwFirstSheet",
    "catDrwStyle",
)

cat_dxf_export_blocks_enum = (
    "catDxfExportBlocksEnumNone",
    "catDxfExportBlocksEnum1Level",
    "catDxfExportBlocksEnumFull",
)

cat_dxf_export_mode_enum = (
    "catDxfExportModeEnumSemantic",
    "catDxfExportModeEnumGraphic",
)

cat_dxf_export_sheets_enum = (
    "catDxfExportSheetsEnumAll",
    "catDxfExportSheetsEnumOnlyCurrent",
)

cat_dxf_export_version_enum = (
    "catDxfExportVersionEnumR12",
    "catDxfExportVersionEnumR13",
    "catDxfExportVersionEnumR14",
    "catDxfExportVersionEnum2000",
    "catDxfExportVersionEnum2004",
    "catDxfExportVersionEnum2007",
)

cat_dxf_import_create_end_points_enum = (
    "catDxfImportCreateEndPointsEnumNever",
    "catDxfImportCreateEndPointsEnumFewEntities",
    "catDxfImportCreateEndPointsEnumAlways",
)

cat_dxf_import_dimensions_enum = (
    "catDxfImportDimensionsEnumDimensions",
    "catDxfImportDimensionsEnumDetails",
    "catDxfImportDimensionsEnumGeometry",
)

cat_dxf_import_unit_enum = (
    "catDxfImportUnitEnumMillimeter",
    "catDxfImportUnitEnumCentimeter",
    "catDxfImportUnitEnumMeter",
    "catDxfImportUnitEnumInch",
    "catDxfImportUnitEnumFoot",
    "catDxfImportUnitEnumScaleFactor",
    "catDxfImportUnitEnumAutomatic",
)

cat_electronic_type = (
    "BOARD",
    "PANEL",
    "COMPONENT",
    "AREA",
    "PCBHOLE",
    "PCBPATTERN",
    "NOPCBBEHAVIOUR",
)

cat_file_selection_mode = (
    "CatFileSelectionModeOpen",
    "CatFileSelectionModeSave",
)

cat_file_type = (
    "catFileTypeText",
    "catFileTypeMotif",
    "catFileTypeHTML",
)

cat_fillet_bitangency_type = (
    "catSphereBitangencyType",
    "catCircleBitangencyType",
)

cat_fillet_boundary_relimitation = (
    "catAutomaticFilletBoundaryRelimitation",
    "catUVFilletBoundaryRelimitation",
    "catConnectFilletBoundaryRelimitation",
    "catMinimumFilletBoundaryRelimitation",
    "catMaximumFilletBoundaryRelimitation",
)

cat_fillet_edge_propagation = (
    "catMinimalFilletEdgePropagation",
    "catTangencyFilletEdgePropagation",
)

cat_fillet_representation = (
    "catFilletRepNone",
    "catFilletRepBoundary",
    "catFilletRepSymbolic",
    "catFilletRepOriginalEdge",
    "catFilletRepProjectedOriginalEdge",
)

cat_fillet_trim_support = (
    "catTrimFilletSupport",
    "catNoTrimFilletSupport",
)

cat_fillet_variation = (
    "catLinearFilletVariation",
    "catCubicFilletVariation",
)

cat_fitting_shuttle_vector = (
    "CATFittingShuttleVectorX",
    "CATFittingShuttleVectorY",
    "CATFittingShuttleVectorZ",
)

cat_full_scene_anti_aliasing_mode = (
    "CATFSAAMode_Deactivated",
    "CATFSAAMode_2xSuperSampling",
    "CATFSAAMode_4xSuperSampling",
    "CATFSAAMode_8xSuperSampling",
    "CATFSAAMode_16xSuperSampling",
)

cat_funct_orientation_direction = (
    "CATFunctNotOriented",
    "CATFunctOrientedUnidirectional",
    "CATFunctOrientedBidirectional",
)

cat_gen_conferencing = (
    "NetMeeting",
    "Backbone",
)

cat_gen_data_save = (
    "NoAutoBackup",
    "AutoBackupEvery",
    "IncrBackup",
)

cat_gen_ui_style = (
    "UIStyleP1",
    "UIStyleP2",
    "UIStyleP3",
)

cat_geometric_type = (
    "catGeoTypeUnknown",
    "catGeoTypeAxis2D",
    "catGeoTypePoint2D",
    "catGeoTypeLine2D",
    "catGeoTypeControlPoint2D",
    "catGeoTypeCircle2D",
    "catGeoTypeHyperbola2D",
    "catGeoTypeParabola2D",
    "catGeoTypeEllipse2D",
    "catGeoTypeSpline2D",
    "catGeoTypePoint",
    "catGeoTypeLine",
    "catGeoTypePlane",
)

cat_grid_position_mode = (
    "catGridPositionMode_Absolute",
    "catGridPositionMode_Relative",
)

cat_hidden_line_mode = (
    "catHlrModeOff",
    "catHlrModeOn",
)

cat_hole_anchor_mode = (
    "catExtremPointHoleAnchor",
    "catMiddlePointHoleAnchor",
)

cat_hole_bottom_type = (
    "catFlatHoleBottom",
    "catVHoleBottom",
    "catTrimmedHoleBottom",
)

cat_hole_thread_side = (
    "catRightThreadSide",
    "catLeftThreadSide",
)

cat_hole_thread_standard = (
    "catHoleMetricThinPitch",
    "catHoleMetricThickPitch",
)

cat_hole_threading_mode = (
    "catThreadedHoleThreading",
    "catSmoothHoleThreading",
)

cat_hole_type = (
    "catSimpleHole",
    "catTaperedHole",
    "catCounterboredHole",
    "catCountersunkHole",
    "catCounterdrilledHole",
)

cat_ig2_export_mode_enum = (
    "catIg2ExportModeEnumSemantic",
    "catIg2ExportModeEnumStructured",
    "catIg2ExportModeEnumGraphic",
)

cat_ig2_export_sheets_enum = (
    "catIg2ExportSheetsEnumAll",
    "catIg2ExportSheetsEnumOnlyCurrent",
)

cat_ig2_import_create_end_points_enum = (
    "catIg2ImportCreateEndPointsEnumNever",
    "catIg2ImportCreateEndPointsEnumFewEntities",
    "catIg2ImportCreateEndPointsEnumAlways",
)

cat_ig2_import_destination_view_enum = (
    "catIg2ImportDestinationViewEnumWorkingViews",
    "catIg2ImportDestinationViewEnumBackground",
)

cat_ig2_import_dimensions_enum = (
    "catIg2ImportDimensionsEnumDimensions",
    "catIg2ImportDimensionsEnumDetails",
    "catIg2ImportDimensionsEnumGeometry",
)

cat_ig2_import_unit_enum = (
    "catIg2ImportUnitEnumMillimeter",
    "catIg2ImportUnitEnumCentimeter",
    "catIg2ImportUnitEnumMeter",
    "catIg2ImportUnitEnumInch",
    "catIg2ImportUnitEnumFoot",
    "catIg2ImportUnitEnumAutomatic",
)

cat_image_rotation = (
    "catImageNoRotation",
    "catImageRotation90",
    "catImageRotation180",
    "catImageRotation270",
    "catImageBestRotation",
)

cat_image_view_mode = (
    "catImageModeOff",
    "catImageModeHRD",
)

cat_insure_view_names_uniqueness_scope = (
    "catInSheet",
    "catInLayout",
)

cat_justification = (
    "catLeft",
    "catCenter",
    "catRight",
)

cat_lighting_mode = (
    "catInfiniteLightSource",
    "catNeonLightSource",
)

cat_limit_mode = (
    "catOffsetLimit",
    "catUpToNextLimit",
    "catUpToLastLimit",
    "catUpToPlaneLimit",
    "catUpToSurfaceLimit",
    "catUpThruNextLimit",
)

cat_manip_auto_insert_mode = (
    "CATOnMouseRelease",
    "CATWhileMouseMoving",
)

cat_manip_clash_mode = (
    "CATManipClashModeNo",
    "CATManipClashModeOn",
    "CATManipClashModeStop",
)

cat_manufacturing_precedence_type = (
    "catPrecedenceTypeJustBefore",
    "catPrecedenceTypeBefore",
)

cat_marker2_d_type = (
    "catMarker2DTypeLine",
    "catMarker2DTypeArrow",
    "catMarker2DTypeRectangle",
    "catMarker2DTypeCircle",
    "catMarker2DTypeFreeHand",
    "catMarker2DTypeText",
    "catMarker2DTypePicture",
)

cat_marker3_d_type = (
    "catMarker3DTypeText",
)

cat_marker_text_orientation = (
    "CatMarkerTextOrientationRight",
    "CatMarkerTextOrientationUp",
    "CatMarkerTextOrientationLeft",
    "CatMarkerTextOrientationDown",
)

cat_measurable_name = (
    "CatMeasurableUnknown",
    "CatMeasurable",
    "CatMeasurableVolume",
    "CatMeasurableSurface",
    "CatMeasurableCylinder",
    "CatMeasurableSphere",
    "CatMeasurableCone",
    "CatMeasurablePlane",
    "CatMeasurableCurve",
    "CatMeasurableCircle",
    "CatMeasurableLine",
    "CatMeasurablePoint",
    "CatMeasurableAxisSystem",
)

cat_merge_mode = (
    "catMergeOff",
    "catMergeOn",
)

cat_multi_selection_mode = (
    "CATMonoSel",
    "CATMultiSelTriggWhenSelPerf",
    "CATMultiSelTriggWhenUserValidatesSelection",
)

cat_navigation_style = (
    "catNavigationExamine",
    "catNavigationWalk",
    "catNavigationFly",
)

cat_optimization_type = (
    "catMinimum",
    "catMaximum",
    "catTargetValue",
    "catOnlyBoundedVariation",
    "catNone",
    "catCstOnly",
)

cat_out_put_format_type = (
    "KWEHtml",
    "KWEText",
    "KWEPrint",
    "KWEEmail",
)

cat_paper_orientation = (
    "catPaperPortrait",
    "catPaperLandscape",
    "catPaperBestFit",
)

cat_paper_size = (
    "catPaperLetter",
    "catPaperLegal",
    "catPaperA0",
    "catPaperA1",
    "catPaperA2",
    "catPaperA3",
    "catPaperA4",
    "catPaperA",
    "catPaperB",
    "catPaperC",
    "catPaperD",
    "catPaperE",
    "catPaperF",
    "catPaperUser",
)

cat_part_elements_naming_mode = (
    "catNoNamingCheck",
    "catNamingCheckUnderSameNode",
    "catNamingCheckWithinUIActiveObject",
)

cat_part_surface_elements_location = (
    "catPartBodyLocation",
    "catXGSLocation",
)

cat_part_update_mode = (
    "catManualUpdate",
    "catAutomaticUpdate",
)

cat_picture_format = (
    "catPictureNONE",
    "catPicturePNG",
    "catPictureJPEG",
    "catPictureCCITTG3",
)

cat_points_projection_mode = (
    "catPointsProjectionModeOff",
    "catPointsProjectionModeOn",
)

cat_print_color = (
    "catColorTrueColor",
    "catColorGreyScale",
    "catColorMonochrome",
)

cat_print_line_cap = (
    "catPrintFlat",
    "catPrintSquare",
    "catPrintRound",
)

cat_print_line_specification = (
    "catPrintAbsolute",
    "catPrintScaled",
    "catPrintNoThickness",
)

cat_print_quality = (
    "catPrintQualityDraft",
    "catPrintQualityLow",
    "catPrintQualityMedium",
    "catPrintQualityHigh",
    "catPrintQualityCustom",
)

cat_print_rendering_mode = (
    "catPrintRenderingModeDefault",
    "catPrintRenderingModeWireframe",
    "catPrintRenderingModeHiddenLineRemoval",
    "catPrintRenderingModeShadingWithTriangles",
    "catPrintRenderingModeDynamicHiddenLineRemoval",
    "catPrintRenderingModeOnScreen",
)

cat_printer_dir_state = (
    "CatPrinterDirFree",
    "CatPrinterDirProtect",
)

cat_prism_extrusion_direction = (
    "catNormalToSketchDirection",
    "catNotNormalToSketchDirection",
)

cat_prism_orientation = (
    "catRegularOrientation",
    "catInverseOrientation",
)

cat_product_source = (
    "catProductSourceUnknown",
    "catProductMade",
    "catProductBought",
)

cat_proj_view_type = (
    "catRightView",
    "catLeftView",
    "catTopView",
    "catBottomView",
    "catRearView",
)

cat_projection_mode = (
    "catProjectionConic",
    "catProjectionCylindric",
    "catProjectionUndefined",
)

cat_psp_idl_application_id = (
    "catPspIDLCATPiping",
    "catPspIDLCATHVAC",
    "catPspIDLCATEquipment",
    "catPspIDLCATWaveguide",
    "catPspIDLCATTubing",
    "catPspIDLCATHanger",
    "catPspIDLCATRaceway",
    "catPspIDLCATConduit",
    "catPspIDLCATCompAccess",
    "catPspIDLCATElectrical",
    "catPspIDLCATPID",
    "catPspIDLCATHVACDiagram",
    "catPspIDLCATTubingDiagram",
    "catPspIDLCATWaveguideDiagram",
    "catPspIDLCATElectricalDiagram",
)

cat_psp_idl_attr_data_type = (
    "catPspIDLInteger",
    "catPspIDLDouble",
    "catPspIDLString",
    "catPspIDLMultiString",
    "catPspIDLBoolean",
)

cat_psp_idl_domain_id = (
    "catPspIDLNone",
    "catPspIDLCATPIP",
    "catPspIDLCATINS",
    "catPspIDLCATHVA",
    "catPspIDLCATEQT",
    "catPspIDLCATTUB",
    "catPspIDLCATMLD",
    "catPspIDLCATWVG",
    "catPspIDLCATRWY",
    "catPspIDLCATCND",
    "catPspIDLCATHGR",
    "catPspIDLCATCAM",
    "catPspIDLCATELE",
)

cat_psp_idl_flow_capability = (
    "catPspIDLFlowCapability_Undefined",
    "catPspIDLFlowCapability_InDirection",
    "catPspIDLFlowCapability_OutDirection",
    "catPspIDLFlowCapability_InOutDirection",
)

cat_psp_idl_flow_reality = (
    "catPspIDLFlowReality_Undefined",
    "catPspIDLFlowReality_InDirection",
    "catPspIDLFlowReality_OutDirection",
    "catPspIDLFlowReality_InOutDirection",
)

cat_psp_idl_function_status = (
    "catPspIDLFuncUndefined",
    "catPspIDLInFuncNet",
    "catPspIDLFuncNetPhysType",
    "catPspIDLFuncNetPhysNoPos",
    "catPspIDLFuncNoNetPhys",
    "catPspIDLFuncNetPhys",
)

cat_psp_idl_part_connector_type = (
    "catPspIDLPartCtrTypeNotRecognized",
    "catPspIDLPartCtrTypeFace",
    "catPspIDLPartCtrTypeSupport",
    "catPspIDLPartCtrTypeCenter",
    "catPspIDLPartCtrTypeTop",
    "catPspIDLPartCtrTypeBottom",
    "catPspIDLPartCtrTypeLeft",
    "catPspIDLPartCtrTypeRight",
    "catPspIDLPartCtrTypeTopLeft",
    "catPspIDLPartCtrTypeTopRight",
    "catPspIDLPartCtrTypeBottomLeft",
    "catPspIDLPartCtrTypeBottomRight",
    "catPspIDLPartCtrTypeCircular",
    "catPspIDLPartCtrTypeRectangular",
    "catPspIDLPartCtrTypeUpOnly",
)

cat_rectangular_pattern_parameters = (
    "catInstancesandSpacing",
    "catUnequalSpacing",
)

cat_rendering_mode = (
    "catRenderShading",
    "catRenderShadingWithEdges",
    "catRenderWireFrame",
    "catRenderHiddenLinesRemoval",
    "catRenderQuickHiddenLinesRemoval",
    "catRenderMaterial",
    "catRenderMaterialWithEdges",
    "catRenderShadingWithEdgesAndHiddenEdges",
    "catRenderShadingWithEdgesWithoutSmoothEdges",
    "catRenderWireFrameWithoutSmoothEdgesWithoutVertices",
    "catRenderWireFrameWithHalfSmoothEdgesWithoutVertices",
    "catRenderShadingWithEdgesWithOutlines",
    "catRenderQuickHiddenLinesRemovalWithoutVertices",
    "catRenderQuickHiddenLinesRemovalWithHiddenEdgesWithOutlines",
    "catRenderQuickHiddenLinesRemovalWithHiddenEdgesWithOutlinesWithoutVertices",
    "catRenderWireFrameWithHalfSmoothEdgeWithOutlinesWithoutVertices",
    "catRenderWireFrameWithOutlinesWithoutSmoothEdgesWithoutVertices",
    "catRenderQuickHiddenLinesRemovalWithHiddenEdgesWithoutSmoothEdgesWithoutVertices",
    "catRenderQuickHiddenLinesRemovalWithHiddenEdgesWithHalfSmoothEdgeWithoutVertices",
    "catRenderQuickHiddenLinesRemovalWithoutSmoothEdgesWithoutVertices",
    "catRenderQuickHiddenLinesRemovalWithHalfSmoothEdgeWithoutVertices",
    "catRenderShadingWithEdgesWithHalfSmoothEdgeWithoutVertices",
    "catRenderShadingWithEdgesWithHalfSmoothEdge",
)

cat_rep_type = (
    "catRep3D",
    "catRep2D",
    "catRepText",
)

cat_representation_mode = (
    "catExactMode",
    "catPolyhedricMode",
    "catVisualMode",
)

cat_sac_settings_enum = (
    "CatSacSettingsEnumNoInsert",
    "CatSacSettingsEnumAutomatic",
    "CatSacSettingsEnumUserPrompt",
)

cat_sampled_analysis_mode = (
    "CatSampledAnalysisOff",
    "CatSampledAnalysisOn",
    "CatSampledAnalysisStop",
    "CatSampledAnalysisVerbose",
)

cat_sampled_split_type = (
    "CatSampledSplitOnSeg",
    "CatSampledSplitOnShot",
)

cat_scene_type = (
    "CatSceneTypeDelta",
    "CatSceneTypeFull",
)

cat_sch_idl_application_id = (
    "catSchIDLCATPID",
    "catSchIDLCATHVACDiagram",
    "catSchIDLCATWaveguideDiagram",
    "catSchIDLCATTubingDiagram",
    "catSchIDLCATElectricalDiagram",
)

cat_sch_idl_arrow_frequency = (
    "catSchIDLArrowAllSegs",
    "catSchIDLArrowAllButLastSeg",
    "catSchIDLArrowInteriorSegs",
    "catSchIDLArrowMiddleSeg",
)

cat_sch_idl_arrow_position = (
    "catSchIDLMidSegArrow",
    "catSchIDLEndSegArrow",
)

cat_sch_idl_arrow_style = (
    "catSchIDLFillArrow",
    "catSchIDLNotFillArrow",
    "catSchIDLStandardArrow",
)

cat_sch_idl_cntr_flow_capability = (
    "catSchIDLCntrFlowCapability_Undefined",
    "catSchIDLCntrFlowCapability_InDirection",
    "catSchIDLCntrFlowCapability_OutDirection",
    "catSchIDLCntrFlowCapability_InOutDirection",
)

cat_sch_idl_cntr_flow_reality = (
    "catSchIDLCntrFlowReality_Undefined",
    "catSchIDLCntrFlowReality_InDirection",
    "catSchIDLCntrFlowReality_OutDirection",
    "catSchIDLCntrFlowReality_InOutDirection",
)

cat_sch_idl_cntr_symbol_type = (
    "catSchIDLCntrSymbol_Undefined",
    "catSchIDLCntrSymbol_Point",
    "catSchIDLCntrSymbol_PtVector",
    "catSchIDLCntrSymbol_OnOffSheet",
    "catSchIDLCntrSymbol_LineBoundary",
)

cat_sch_idl_display_mode = (
    "catSchIDLDisplayMode_Default",
    "catSchIDLDisplayMode_Alternate",
)

cat_sch_idl_extension_type = (
    "catSchIDLComponent_Extension",
    "catSchIDLRoute_Extension",
    "catSchIDLCompConnector_Extension",
    "catSchIDLRouteConnector_Extension",
    "catSchIDLZone_Extension",
)

cat_sch_idl_gap_priority = (
    "catSchIDLGapThisRoute",
    "catSchIDLGapInputRoute",
    "catSchIDLGapNoPriority",
    "catSchIDLGapHorizontalSeg",
    "catSchIDLGapVerticalSeg",
)

cat_sch_idl_gap_style = (
    "catSchIDLBlankGap",
    "catSchIDLJumpGap",
    "catSchIDLWavyGap",
)

cat_sch_idl_internal_flow_status = (
    "catSchIDLInternFlowStatus_Undefined",
    "catSchIDLInternFlowStatus_Open",
    "catSchIDLInternFlowStatus_Close",
)

cat_sch_idl_internal_flow_type = (
    "catSchIDLInternFlowType_Undefined",
    "catSchIDLInternFlowType_Corner",
    "catSchIDLInternFlowType_Linear",
)

cat_sch_idl_multi_image_status = (
    "catSchIDLImage_IsUpToDate",
    "catSchIDLImage_MasterNotFound",
    "catSchIDLImage_MasterDocNotFound",
    "catSchIDLImage_InvalidReference",
    "catSchIDLImage_AttrsNotUpToDate",
)

cat_sch_idl_route_alternate_graphic_style = (
    "catSchIDLRouteAlternateGraphicStyle_ellipse",
)

cat_sch_idl_route_compress_mode = (
    "catSchIDLCompressOff",
    "catSchIDLCompressOn",
)

cat_sch_idl_route_mode = (
    "catSchIDLRouteMode_Undefined",
    "catSchIDLRouteMode_HorizontalVertical",
    "catSchIDLRouteMode_HorizontalVertical45",
    "catSchIDLRouteMode_PointToPoint",
    "catSchIDLRouteMode_AroundObject",
)

cat_sch_idl_route_symbol_update_mode = (
    "catSchIDLSymbolUpdateOff",
    "catSchIDLSymbolUpdateOn",
)

cat_sch_idl_route_unset_gaps_mode = (
    "catSchIDLUnsetGapsOff",
    "catSchIDLUnsetGapsOn",
)

cat_sch_idlgrr_route_reshape_mode = (
    "catSchIDLFixedShapeOff",
    "catSchIDLFixedShapeOn",
)

cat_script_language = (
    "CATVBScriptLanguage",
    "CATVBALanguage",
    "CATBasicScriptLanguage",
    "CATJavaLanguage",
    "CATJScriptLanguage",
)

cat_script_library_type = (
    "catScriptLibraryTypeDocument",
    "catScriptLibraryTypeDirectory",
    "catScriptLibraryTypeVBAProject",
)

cat_search_context_scope = (
    "Everywhere",
    "InWorkbench",
    "FromWorkbench",
    "FromSelection",
    "VisibleOnScreen",
)

cat_sec_window_open_mode = (
    "catSecWindow_DefaultSize",
    "catSecWindow_TileVertically",
)

cat_section_behavior = (
    "catSectionBehaviorManual",
    "catSectionBehaviorAutomatic",
    "catSectionBehaviorFreeze",
)

cat_section_clipping_mode = (
    "catSection_Software",
    "catSection_OpenGL",
)

cat_section_grid_style = (
    "catSectionGridStyle_Lines",
    "catSectionGridStyle_Crosses",
)

cat_section_plane_normal = (
    "catSectionNormal_X",
    "catSectionNormal_Y",
    "catSectionNormal_Z",
)

cat_section_plane_origin = (
    "catSectionOrigin_0",
    "catSectionOrigin_Selection",
)

cat_section_type = (
    "catSectionTypePlane",
    "catSectionTypeSlice",
    "catSectionTypeBox",
)

cat_selection_filter = (
    "ZeroDim",
    "MonoDim",
    "MonoDimInfinite",
    "RectilinearMonoDim",
    "RectilinearMonoDimInfinite",
    "BiDim",
    "BiDimInfinite",
    "PlanarBiDim",
    "PlanarBiDimInfinite",
    "CylindricalBiDim",
    "TriDim",
)

cat_sewing_intersection_mode = (
    "catSewingNoIntersect",
    "catSewingIntersect",
)

cat_sheet_gen_views_pos_mode = (
    "catFixedCG",
    "catFixedAxis",
)

cat_sheet_projection_method = (
    "catFirstAngle",
    "catThirdAngle",
)

cat_show_result_type = (
    "ByRule",
    "ByObject",
    "ByState",
)

cat_shuttle_move_mode = (
    "CatShuttle",
    "CatAxis",
)

cat_shuttle_vector = (
    "CatShuttleVectorX",
    "CatShuttleVectorY",
    "CatShuttleVectorZ",
)

cat_solve_type = (
    "ManualSolveType",
    "AutomaticOptimizedSolveType",
    "AutomaticCompleteSolveType",
)

cat_specs_and_geom_window_layout = (
    "catWindowSpecsOnly",
    "catWindowGeomOnly",
    "catWindowSpecsAndGeom",
)

cat_specs_layout = (
    "catSpecsViewerHorizontalIndented",
    "catSpecsViewerHorizontalUp",
    "catSpecsViewerHorizontalCentered",
    "catSpecsViewerVerticalCentered",
    "catSpecsViewerHorizontalRelational",
    "catSpecsViewerVerticalRelational",
)

cat_split_side = (
    "catPositiveSide",
    "catNegativeSide",
)

cat_str_creation_mode = (
    "catStrPartMode",
    "catStrSheetMetalMode",
)

cat_str_cutback_type = (
    "catStrNoneType",
    "catStrNormalType",
    "catStrWeldedType",
    "catStrMiteredType",
    "catStrNotchingType",
)

cat_str_link_mode = (
    "catStrWithLinkMode",
    "catStrNoLinkMode",
    "catStrRefRefWithLinkMode",
    "catStrRefRefNoLinkMode",
)

cat_str_material_orientation = (
    "catStrStandardOrientation",
    "catStrReverseOrientation",
)

cat_str_member_extremity = (
    "catStartExtremity",
    "catEndExtremity",
    "catBothExtremity",
)

cat_str_placement_point = (
    "catStrDefault",
    "catStrBottomLeft",
    "catStrBottomCenter",
    "catStrBottomRight",
    "catStrCenterLeft",
    "catStrCenterCenter",
    "catStrCenterRight",
    "catStrTopLeft",
    "catStrTopCenter",
    "catStrTopRight",
    "catStrGravity",
    "catStrGravityBottom",
    "catStrGravityLeft",
    "catStrGravityRight",
    "catStrGravityTop",
    "catStrUserPoint",
)

cat_str_plane_mode = (
    "catStrNoneMode",
    "catStrOnPlane",
    "catStrParallelToPlane",
)

cat_str_section_properties = (
    "CatStrArea",
    "CatStrInertiaXX",
    "CatStrInertiaYY",
    "CatStrModuleInertiaX",
    "CatStrModuleInertiaY",
    "CatStrGirationModuleX",
    "CatStrGirationModuleY",
)

cat_symbol_type = (
    "catNotUsed",
    "catCross",
    "catPlus",
    "catConcentric",
    "catCoincident",
    "catFullCircle",
    "catFullSquare",
    "catStar",
    "catDot",
    "catSmallDot",
    "catMisc1",
    "catMisc2",
    "catFullCircle2",
    "catFullSquare2",
    "catOpenArrow",
    "catUnfilledArrow",
    "catBlankedArrow",
    "catFilledArrow",
    "catUnfilledCircle",
    "catBlankedCircle",
    "catFilledCircle",
    "catCrossedCircle",
    "catBlankedSquare",
    "catFilledSquare",
    "catBlankedTriangle",
    "catFilledTriangle",
    "catManipulatorSquare",
    "catMamipulatorDiamond",
    "catManipulatorCircle",
    "catManipulatorTriangle",
    "catDoubleOpenArrow",
    "catWave",
)

cat_table_border_type = (
    "CatTableNone",
    "CatTableLeft",
    "CatTableTop",
    "CatTableRight",
    "CatTableBottom",
    "CatTableBackSlashed",
    "CatTableSlashed",
    "CatTableHorStrikedOut",
    "CatTableVerStrikedOut",
    "CatTableOutLine",
    "CatTableInside",
    "CatTableCross",
)

cat_table_compute_mode = (
    "CatTableComputeOFF",
    "CatTableComputeON",
)

cat_table_invert_mode = (
    "CatInvertColumn",
    "CatInvertRow",
    "CatInvertAll",
)

cat_table_position = (
    "CatTableTopLeft",
    "CatTableMiddleLeft",
    "CatTableBottomLeft",
    "CatTableTopCenter",
    "CatTableMiddleCenter",
    "CatTableBottomCenter",
    "CatTableTopRight",
    "CatTableMiddleRight",
    "CatTableBottomRight",
)

cat_text_anchor_position = (
    "catUnsusedValue1",
    "catTopLeft",
    "catMiddleLeft",
    "catBottomLeft",
    "catTopCenter",
    "catMiddleCenter",
    "catBottomCenter",
    "catTopRight",
    "catMiddleRight",
    "catBottomRight",
    "catUnsusedValue2",
    "catCapLeft",
    "catHalfLeft",
    "catBaseLeft",
    "catCapCenter",
    "catHalfCenter",
    "catBaseCenter",
    "catCapRight",
    "catHalfRight",
    "catBaseRight",
)

cat_text_flip_mode = (
    "catTextNoFlip",
    "catTextHorizontalFlip",
    "catTextVerticalFlip",
    "catTextHorizontalAndVerticalFlip",
    "catTextAutoFlip",
)

cat_text_frame_type = (
    "catNone",
    "catRectangle",
    "catSquare",
    "catCircle",
    "catScoredCircle",
    "catDiamond",
    "catTriangle",
    "catRightFlag",
    "catLeftFlag",
    "catBothFlag",
    "catOblong",
    "catEllipse",
    "catCustom",
)

cat_text_property = (
    "catBold",
    "catItalic",
    "catUnderline",
    "catOverline",
    "catStrikethrough",
    "catSubscript",
    "catSuperscript",
    "catFontSize",
    "catParagraph",
    "catPlain",
    "catColor",
    "catFontName",
    "catBorder",
    "catAlignment",
    "catCharRatio",
    "catCharSpacing",
    "catKerning",
)

cat_thread_linked_to = (
    "catNotDefined",
    "catNoLink",
    "cat2DPoint",
    "cat2DCircle",
    "cat3DGeom",
    "cat3DHole",
    "cat3DThread",
)

cat_thread_polarity = (
    "catThread",
    "catTap",
)

cat_thread_side = (
    "catRightSide",
    "catLeftSide",
)

cat_thread_standard = (
    "catMetricThinPitch",
    "catMetricThickPitch",
)

cat_thread_type = (
    "catThreaded",
    "catTaped",
)

cat_tree_orientation_enum = (
    "catTreeOrientationVertical",
    "catTreeOrientationHorizontal",
)

cat_tree_size_type_enum = (
    "catTreeSizeTypeFixedSize",
    "catTreeSizeTypeTextDependentSize",
)

cat_tree_type_enum = (
    "catTreeTypeClassical",
    "catTreeTypeStructural",
    "catTreeTypeHistorical",
    "catTreeTypeRelational",
)

cat_view2_d_mode_visu = (
    "catView2DModeNotActivated",
    "catView2DModeNoShow",
)

cat_view_background_mode = (
    "catStandard",
    "catInvisible",
    "catUnpickable",
    "catLowIntensity",
    "catUnpickableLowIntensity",
)

cat_view_filter_creation_mode = (
    "catDefaultFilter",
    "catDisplayFilterDialogBox",
    "catDedicatedFilter",
)

cat_view_side = (
    "catTopSide",
    "catBottomSide",
    "catLeftSide",
    "catRightSide",
    "catTLCorner",
    "catTRCorner",
    "catBLCorner",
    "catBRCorner",
)

cat_view_type = (
    "catAuxiliaryView",
    "catSectionView",
    "catSectionCutView",
)

cat_vis_layer_type = (
    "catVisLayerBasic",
    "catVisLayerNone",
)

cat_vis_property_pick = (
    "catVisPropertyPickAttr",
    "catVisPropertyNoPickAttr",
)

cat_vis_property_show = (
    "catVisPropertyShowAttr",
    "catVisPropertyNoShowAttr",
)

cat_vis_property_status = (
    "catVisPropertyDefined",
    "catVisPropertyUnDefined",
)

cat_vis_property_type = (
    "catVisPropertyLineType",
    "catVisPropertyWidth",
    "catVisPropertyColor",
    "catVisPropertyOpacity",
)

cat_visu_background_mode = (
    "catNoBackground",
    "catPick",
    "catNoPick",
    "catLowIntPick",
    "catLowIntNoPick",
)

cat_visu_in3_d_mode = (
    "catShowAll",
    "catHideAll",
)

cat_visualization_type = (
    "Passed",
    "Failed",
    "Both",
)

cat_weld_additional_symbol = (
    "catNoneAddWelding",
    "catFlatWelding",
    "catConvexWelding",
    "catConcaveWelding",
    "catFlushWelding",
    "catSmoothWelding",
)

cat_welding = (
    "catNoneWelding",
    "catFirstWelding",
    "catSecondWelding",
)

cat_welding_field = (
    "catWeldingNone",
    "catWeldingFieldOne",
    "catWeldingFieldTwo",
    "catWeldingFieldThree",
    "catWeldingFieldFour",
    "catWeldingFieldFive",
    "catWeldingFieldSix",
    "catWeldingFieldSeven",
)

cat_welding_side = (
    "catWeldingUp",
    "catWeldingDown",
)

cat_welding_symbol = (
    "catNoneMainWelding",
    "catSquareWelding",
    "catVGrooveWelding",
    "catHVGrooveWelding",
    "catYGrooveWelding",
    "catHYGrooveWelding",
    "catUGrooveWelding",
    "catHUGrooveWelding",
    "catFilletWelding",
    "catCFlangeWelding",
    "catEFlangeWelding",
    "catVFlareWelding",
    "catHVFlareWelding",
    "catSpotWelding",
    "catBackWelding",
    "catHVOGrooveWelding",
    "catVOGrooveWelding",
    "catPlugWelding",
    "catMRWelding",
    "catMWelding",
    "catRechargWelding",
    "catSpotJISWelding",
    "catEFlangeISOWelding",
    "catSeamWelding",
    "catScarfWelding",
    "catStudWelding",
    "catEdgeWelding",
    "catMeltThruWelding",
    "catSurfaceJointWelding",
    "catInclinedJointWelding",
)

cat_window_state = (
    "catWindowStateMaximized",
    "catWindowStateMinimized",
    "catWindowStateNormal",
)

cat_work_mode_type = (
    "DEFAULT_MODE",
    "VISUALIZATION_MODE",
    "DESIGN_MODE",
)

catfta_dim_configure_snapping = (
    "CATFTADimSnappingUndefined",
    "CATFTADimSnappingOnGrid",
    "CATFTADimSnappingValue",
    "CATFTADimSnappingBoth",
)

catfta_dim_create_on = (
    "CATFTADimCreateOnUndefined",
    "CATFTADimCreateOnCenter",
    "CATFTADimCreateOnEdge",
)

catfta_leader_associativity = (
    "CATFTALeaderAssociativityUndefined",
    "CATFTALeaderAssociativityFree",
    "CATFTALeaderAssociativityPerpendicular",
)

catv4_iv4_v5_spec_draft_migration_enum = (
    "squareMode",
    "coneMode",
)

catv4_iv5_v4_associativity_mode_enum = (
    "AssociativeMode",
    "NonAssociativeMode",
    "NonAssociativityModeAndNoSolidCreation",
)

catv4_iv5_v4_error_feature_creation_enum = (
    "NeverCreateErrorFeatures",
    "CreateAnErrorFeatureAfterUserAgreement",
    "AlwaysCreateErrorFeatures",
)

catv4_iv5_v4_internal_curve_creation_enum = (
    "AllCurvesAreCreated",
    "OnlyConicsAreCreated",
    "NoInternalCurveIsCreated",
)

cd5_save_item_status = (
    "CD5SaveItem_New",
    "CD5SaveItem_Modified",
    "CD5SaveItem_Exists",
    "CD5SaveItem_ECNameNotUnique",
    "CD5SaveItem_ModifiedNotLockedByYou",
    "CD5SaveItem_Obsolete",
    "CD5SaveItem_UUIDConflict",
    "CD5SaveItem_NotFound",
)

cd5_save_operation_scope = (
    "CD5SaveOperation_ActiveDocument",
    "CD5SaveOperation_CurrentEditor",
    "CD5SaveOperation_Session",
)

contact_stiffness_type = (
    "DEFAULT",
    "STIFF_VALUE",
)

distribution_type = (
    "UNIFORM",
    "JOB",
    "USERDEFINED",
    "JOB_USERDEFINED",
)

dmu_track_move_mode = (
    "DMUTrackSpeedMode",
    "DMUTrackTimeMode",
)

dnb_act_behavior_type = (
    "DNBBehaviorProcess",
    "DNBBehaviorParent",
)

dnb_analysis_level = (
    "DNBAnalysisLevelOff",
    "DNBAnalysisLevelHighlight",
    "DNBAnalysisLevelVerbose",
    "DNBAnalysisLevelInterrupt",
)

dnb_assign_status = (
    "DNBUnknownState",
    "DNBSuccess",
    "DNBAlreadyAssigned",
    "DNBInvalidObjetAssignment",
    "DNBInvalidProcessVersion",
    "DNBPartsNotLoaded",
)

dnb_auxilliary_device_type = (
    "AuxilliaryDeviceType_RailTrackGantry",
    "AuxilliaryDeviceType_EndOfArmTooling",
    "AuxilliaryDeviceType_WorkpiecePositioner",
    "AuxilliaryDeviceType_Conveyor",
)

dnb_hlnk_behavior_type = (
    "DNBBehaviorContinue",
    "DNBBehaviorPause",
)

dnb_sim_graph_update_mode = (
    "DNBSimGraphUpdateDisabled",
    "DNBSimGraphUpdateEnabled",
)

dnb_sim_init_state_attr = (
    "DNBVisInitStateAttr",
    "DNBPosInitStateAttr",
    "DNBColInitStateAttr",
    "DNBOpacInitStateAttr",
    "DNBVisPosInitStateAttr",
    "DNBVisColInitStateAttr",
    "DNBVisOpacInitStateAttr",
    "DNBVisPosColInitStateAttr",
    "DNBVisPosOpacInitStateAttr",
    "DNBVisColOpacInitStateAttr",
    "DNBPosColInitStateAttr",
    "DNBPosOpacInitStateAttr",
    "DNBPosColOpacInitStateAttr",
    "DNBColOpacInitStateAttr",
    "DNBAllInitStateAttr",
)

dnb_sim_navigation_mode = (
    "DNBSimNavigationModeStep",
    "DNBSimNavigationModeAnimate",
)

dnb_visualization_mode = (
    "DNBVisualizationModeHighlight",
    "DNBVisualizationModeCurves",
)

dnbia_mfg_assembly_type = (
    "manufacturingAssembly",
    "manufacturingKit",
    "assemblySpecTree",
    "manufacturingOutput",
    "notSpecified",
)

dnbppr_remove_status = (
    "DNBFastenerUnknownStatus",
    "DNBFastenerAssignedStatus",
    "DNBFastenerSuccessStatus",
)

dnbtcp_trace_legends = (
    "DNBTCPTraceLegendAllLegend",
    "DNBTCPTraceLegendName",
    "DNBTCPTraceLegendX",
    "DNBTCPTraceLegendY",
    "DNBTCPTraceLegendZ",
    "DNBTCPTraceLegendYaw",
    "DNBTCPTraceLegendPitch",
    "DNBTCPTraceLegendRoll",
    "DNBTCPTraceLegendCycleTime",
    "DNBTCPTraceLegendHighlight",
    "DNBTCPTraceLegendAlwaysVisible",
)

dnbtcp_trace_reps = (
    "DNBTCPTraceRepAllRep",
    "DNBTCPTraceRepPoint",
    "DNBTCPTraceRepLine",
    "DNBTCPTraceRepAxis",
)

elem_behav_enum = (
    "BEHAVIOR_NONE",
    "SHELL",
    "MEMBRANE",
    "SOLID3D",
    "CONTINUUM_SHELL",
    "BEAM",
    "GASKET",
)

elem_id_enum = (
    "TET_LINEAR",
    "TET_PARABOLIC",
    "HEX_LINEAR",
    "HEX_PARABOLIC",
    "WEDG_LINEAR",
    "WEDG_PARABOLIC",
    "TRI_LINEAR",
    "TRI_PARABOLIC",
    "QUAD_LINEAR",
    "QUAD_PARABOLIC",
    "LINE_LINEAR",
    "LINE_PARABOLIC",
)

fixed_time_increment_method = (
    "ABQ_FTI_ELEMENT_BY_ELEMENT",
    "ABQ_FTI_USER_DEFINED",
)

formulation_option_type = (
    "SOLVERDEFAULT",
    "SURFACETOSURFACE",
    "NODETOSURFACE",
)

formulation_type = (
    "FRICTIONLESS",
    "PENALTY",
)

frame_visibility = (
    "VisNo",
    "VisYes",
    "VisRetain",
)

hts_activity_group_motion_basis = (
    "HAGMOTBASIS_DEFAULT",
    "HAGMOTBASIS_USERSPEED",
    "HAGMOTBASIS_USERTIME",
)

hts_body_pose_options = (
    "BODYPOSE_CURRENT",
    "BODYPOSE_RESET",
)

hts_end_effector = (
    "EE_LEFTHAND",
    "EE_RIGHTHAND",
    "EE_LEFTLEG",
    "EE_RIGHTLEG",
    "EE_LINEOFSIGHT",
    "EE_BODY",
    "EE_NECK",
)

hts_hand = (
    "HAND_RIGHT",
    "HAND_LEFT",
)

hts_manikin_referential = (
    "REF_EYEPOINT",
    "REF_HPOINT",
    "REF_LEFTFOOT",
    "REF_RIGHTFOOT",
    "REF_LOWESTFOOT",
    "REF_CROTCH",
    "REF_LEFTHAND",
    "REF_RIGHTHAND",
    "REF_BETWEENFEET",
    "REF_HPOINTPROJECTION",
)

hts_motion_basis = (
    "MOTBASIS_SPEED",
    "MOTBASIS_TIME",
)

hts_pick_type = (
    "SINGLE_HAND",
    "BOTH_HANDS",
)

hts_search_intensity = (
    "FINESEARCH",
    "NORMALSEARCH",
    "COARSESEARCH",
)

hts_stride_options = (
    "STRIDE_SHORT",
    "STRIDE_MEDIUM",
    "STRIDE_LONG",
)

hts_swing_options = (
    "SWING_BOTHARMS",
    "SWING_LEFTARM",
    "SWING_RIGHTARM",
    "SWING_CURRENT",
)

hts_walk_motion_basis = (
    "WALKMOTBASIS_DEFAULT",
    "WALKMOTBASIS_USERSPEED",
    "WALKMOTBASIS_USERTIME",
)

incrementation_type = (
    "AUTO_INCREMENT",
    "FIXED_INCREMENT",
)

initial_thickness_type = (
    "USE_NODAL_COORDINATES",
    "INITIAL_THICKNESS_SPECIFY",
)

item_assignment_type = (
    "ProcessProcesses",
    "ProcessFirstProcesses",
    "ProcessRemoves",
    "ProcessImplementsRequirementPartial",
    "ProcessImplementsRequirementComplete",
    "productviewpoint",
    "productvisualization",
)

job_type = (
    "ANALYSIS",
    "DATACHECK",
    "CONTINUE",
    "FROMINPUTFILE",
    "SYNTAXCHECK",
    "RESTART",
)

max_stiffness_type = (
    "MAX_STIFF_DEFAULT",
    "MAX_STIFF_VALUE",
)

memory_unit_type = (
    "MEGABYTES",
    "PERCENT",
)

motion_basis = (
    "MOTION_ABSOLUTE",
    "MOTION_PERCENT",
    "MOTION_TIME",
)

parallel_method_std_type = (
    "TREE",
    "SUPERNODE",
)

position_tolerance_type = (
    "COMPUTED",
    "SPECIFIED",
)

pressure_overclosure_type = (
    "HARD",
    "EXPONENTIAL",
    "LINEAR",
    "TABULAR",
)

raster_level_of_detail = (
    "LowQuality",
    "NormalQuality",
    "HighQuality",
    "Customize",
)

response_type = (
    "STEADY_STATE",
    "TRANSIENT",
)

sliding_type = (
    "FINITE",
    "SMALL",
)

spm_distribution_mode = (
    "SPM_LINEAR",
    "SPM_HISTOGRAM",
    "SPM_LOG",
)

spring_def_type = (
    "ABQ_LINE",
    "ABQ_NON_LINEAR",
)

spring_dof_type = (
    "U1_DOF",
    "U2_DOF",
    "U3_DOF",
    "UR1_DOF",
    "UR2_DOF",
    "UR3_DOF",
)

spring_type_type = (
    "AXIAL",
    "GENERAL",
)

stabilization_stiffness_type = (
    "STABILIZATION_DEFAULT",
    "STABILIZATION_SPECIFY",
)

stabilization_type = (
    "NONE",
    "DISSIPATION",
    "FACTOR",
)

swk_posture_spec = (
    "SWKPostureSpecDefault",
    "SWKPostureSpecStand",
    "SWKPostureSpecSit",
    "SWKPostureSpecReach",
    "SWKPostureSpecExtendedReach",
    "SWKPostureSpecSpan",
    "SWKPostureSpecKneel",
    "SWKPostureSpecInitial",
)

time_span_type = (
    "STEP_TIME",
    "TOTAL_TIME",
)



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.general_statistics_setting_att import GeneralStatisticsSettingAtt


class ErrorlogStatisticsSettingAtt(GeneralStatisticsSettingAtt):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         System.GeneralStatisticsSettingAtt
                |                             ErrorlogStatisticsSettingAtt
                | 
                | Interface for Errorlog statistic Controller.
                | 
                | Role: the errorlog statistics controller manages the values of all or only a
                | part of the attributes available for the thematic.
                | For the definitions of methods and variables common to every thematic, see the
                | GeneralStatisticsSettingAtt
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.errorlog_statistics_setting_att = com_object

    @property
    def abnd(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property ABND() As boolean
                | 
                |     Returns or sets the state ot the abend severity level
                |     field.
                |     Role: Returns or sets the state ot the abend severity level
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.ABND

    @abnd.setter
    def abnd(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.ABND = value

    @property
    def cerr(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property CERR() As boolean
                | 
                |     Returns or sets the state ot the critical error severity level
                |     field.
                |     Role: Returns or sets the state ot the critical error severity level
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.CERR

    @cerr.setter
    def cerr(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.CERR = value

    @property
    def cmnd(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property CMND() As boolean
                | 
                |     Returns or sets the state ot the command name field.
                |     Role: Returns or sets the state ot the command name field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.CMND

    @cmnd.setter
    def cmnd(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.CMND = value

    @property
    def comt(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property COMT() As boolean
                | 
                |     Returns or sets the state ot the abend comment level
                |     field.
                |     Role: Returns or sets the state ot the comment severity level
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.COMT

    @comt.setter
    def comt(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.COMT = value

    @property
    def msge(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property MSGE() As boolean
                | 
                |     Returns or sets the state ot the message field.
                |     Role: Returns or sets the state ot the message field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.MSGE

    @msge.setter
    def msge(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.MSGE = value

    @property
    def urep(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property UREP() As boolean
                | 
                |     Returns or sets the state ot the user report severity level
                |     field.
                |     Role: Returns or sets the state ot the user report severity level
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.UREP

    @urep.setter
    def urep(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.UREP = value

    @property
    def warn(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property WARN() As boolean
                | 
                |     Returns or sets the state ot the warning severity level
                |     field.
                |     Role: Returns or sets the state ot the warning severity level
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.WARN

    @warn.setter
    def warn(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.WARN = value

    @property
    def wkbn(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property WKBN() As boolean
                | 
                |     Returns or sets the state ot the workbench name field.
                |     Role: Returns or sets the state ot the workbench name
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.errorlog_statistics_setting_att.WKBN

    @wkbn.setter
    def wkbn(self, value):
        """
        :param bool value:
        """

        self.errorlog_statistics_setting_att.WKBN = value

    def __repr__(self):
        return f'ErrorlogStatisticsSettingAtt(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.space_analyses_interfaces.conflicts import Conflicts
from pycatia.system_interfaces.any_object import AnyObject


class ClashResult(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ClashResult
                | 
                | Represents the ClashResult object.
                | The ClashResult object is a set of conflicts resulting from a clash
                | detection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.clash_result = com_object

    @property
    def conflicts(self) -> Conflicts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Conflicts() As Conflicts (Read Only)
                | 
                |     Returns the collection of computed Conflicts.
                | 
                |     Example:
                | 
                |              This example retrieves the conflicts of NewClashResult
                |              ClashResult.
                |             
                | 
                |             Dim NewConflicts As Conflicts
                |             Set NewConflicts = NewClashResult.Conflicts

        :return: Conflicts
        :rtype: Conflicts
        """

        return Conflicts(self.clash_result.Conflicts)

    def export(self, i_type: int, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Export(CatClashExportType iType,
                | CATBSTR iPath)
                | 
                |     Exports the results in a XML file.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of export. 
                |         iPath
                |             The path of the file. 
                | 
                |     Example:
                | 
                |              This example exports the results of NewClashResult
                |              ClashResult.
                |             
                | 
                |             Dim ThePath As String
                |             NewClashResult.Export CatClashExportTypeXMLResultOnly,
                |             "c:\\tmp\\sample.xml"

        :param int i_type:
        :param str i_path:
        :return: None
        :rtype: None
        """
        return self.clash_result.Export(i_type, i_path)

    def __repr__(self):
        return f'ClashResult(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.cat_base_dispatch import CATBaseDispatch


class DrawingViewGenerativeLinks(CATBaseDispatch):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 DrawingViewGenerativeLinks
                | 
                | Represents the generative links of a drawing view.
                | 
                | The generative links of a drawing view is an object that manages the way the
                | generative view points at the 3D document.
    
    """

    def __init__(self, com_object):
        super().__init__()
        self.drawing_view_generative_links = com_object

    def add_link(self, i_link: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AddLink(AnyObject iLink)
                | 
                |     Adds a link to the drawing view.
                | 
                |     Example:
                |         This example adds a link to the Part document MyPartDocument to the
                |         MyView drawing view.
                | 
                |          Dim viewLinks As DrawingViewGenerativeLinks
                |          Set viewLinks = MyView.GenerativeLinks
                |          viewLinks.AddLink(MyPartDocument)

        :param AnyObject i_link:
        :return: None
        :rtype: None
        """
        return self.drawing_view_generative_links.AddLink(i_link.com_object)

    def copy_links_to(self, i_links: 'DrawingViewGenerativeLinks') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub CopyLinksTo(DrawingViewGenerativeLinks iLinks)
                | 
                |     Copies the links of the drawing view.
                | 
                |     Example:
                |         This example copies the links of the MyView drawing view to the MyLinks
                |         object.
                | 
                |          Dim viewLinks As DrawingViewGenerativeLinks
                |          Set viewLinks = MyView.GenerativeLinks
                |          Dim MyLinks As DrawingViewGenerativeLinks
                |          viewLinks.CopyLinksTo(MyLinks)

        :param DrawingViewGenerativeLinks i_links:
        :return: None
        :rtype: None
        """
        return self.drawing_view_generative_links.CopyLinksTo(i_links.drawing_view_generative_links)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'copy_links_to'
        # # vba_code = """
        # # Public Function copy_links_to(drawing_view_generative_links)
        # #     Dim iLinks (2)
        # #     drawing_view_generative_links.CopyLinksTo iLinks
        # #     copy_links_to = iLinks
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def first_link(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func FirstLink() As AnyObject
                | 
                |     Returns the first link of the drawing view.
                | 
                |     Example:
                |         This example retrieves the first link of the MyView drawing
                |         view.
                | 
                |          Dim viewLinks As DrawingViewGenerativeLinks
                |          Set viewLinks = MyView.GenerativeLinks
                |          Dim firstLink As AnyObject
                |          Set firstLink = MyView.FirstLink()

        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.drawing_view_generative_links.FirstLink())

    def next_link(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func NextLink() As AnyObject
                | 
                |     Returns the next link of the drawing view.
                | 
                |     Example:
                |         This example retrieves the next link of the MyView drawing
                |         view.
                | 
                |          Dim viewLinks As DrawingViewGenerativeLinks
                |          Set viewLinks = MyView.GenerativeLinks
                |          Dim nextLink As AnyObject
                |          nextLink = viewLinks.NextLink()

        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.drawing_view_generative_links.NextLink())

    def remove_all_links(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemoveAllLinks()
                | 
                |     Removes all links of the drawing view.
                | 
                |     Example:
                |         This example retrieves all links of the MyView drawing
                |         view.
                | 
                |          Dim viewLinks As DrawingViewGenerativeLinks
                |          Set viewLinks = MyView.GenerativeLinks
                |          viewLinks.RemoveAllLinks()

        :return: None
        :rtype: None
        """
        return self.drawing_view_generative_links.RemoveAllLinks()

    def __repr__(self):
        return f'DrawingViewGenerativeLinks()'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.folder import Folder
from pycatia.system_interfaces.collection import Collection


class Folders(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Folders
                | 
                | The folders object belongs to a folder.
                | It lists all the folders contained in the folder. It allows to retrieve Folder
                | objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Folder)
        self.folders = com_object

    def item(self, i_number: int) -> Folder:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(long iNumber) As Folder
                | 
                |     Returns a folder using its index or its name from the folder
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the folder to retrieve from the collection
                |             of folders. As a numerics, this index is the rank of the folder in the
                |             collection. The index of the first folder in the collection is 1, and the index
                |             of the last folder is Count. As a string, it is the name you assigned to the
                |             folder using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved folder 
                |     Example:
                |         This example retrieves in ThisFolder the third folder, and it
                |         ThatFolder the folder named MyFolder. in the TestFolders folder
                |         collection.
                | 
                |          Dim ThisFolder As Folder
                |          Set ThisFolder = TestFolders.Item(3)
                |          Dim ThatFolder As Folder
                |          Set ThatFolder = TestFolders.Item("MyFolder")

        :param int i_number:
        :return: Folder
        :rtype: Folder
        """
        return Folder(self.folders.Item(i_number))

    def __getitem__(self, n: int) -> Folder:
        if (n + 1) > self.count:
            raise StopIteration

        return Folder(self.folders.item(n + 1))

    def __iter__(self) -> Iterator[Folder]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Folders(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.drafting_interfaces.drawing_arrow import DrawingArrow
from pycatia.system_interfaces.collection import Collection


class DrawingArrows(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingArrows
                | 
                | A collection of all the drawing arrows currently managed by a drawing view of
                | drawing sheet in a drawing document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingArrow)
        self.drawing_arrows = com_object

    def add(self,
            i_head_point_x: float,
            i_head_point_y: float,
            i_tail_point_x: float,
            i_tail_point_y: float) -> DrawingArrow:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(double iHeadPointX,
                | double iHeadPointY,
                | double iTailPointX,
                | double iTailPointY) As DrawingArrow
                | 
                |     Creates a drawing arrow and adds it to the DrawingArrows
                |     collection.
                | 
                |     Parameters:
                | 
                |         iHeadPointX,iHeadPointY
                |             The x and y coordinates of head side of drawing arrow
                |             
                |         iTailPointX,iTailPointY
                |             The x and y coordinates of tail side of drawing arrow
                |             
                | 
                |     Returns:
                |         The created drawing arrow 
                | 
                | Example:
                |     The following example creates a drawing arrow and retrieved in MyArrow in
                |     the drawing view collection of the MyView drawing view. This view belongs to
                |     the drawing view collection of the drawing sheet
                | 
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim MyArrow As DrawingArrow
                |      Set MyArrow = MyView.Arrows.Add(0., 0., 20., 50)

        :param float i_head_point_x:
        :param float i_head_point_y:
        :param float i_tail_point_x:
        :param float i_tail_point_y:
        :return: DrawingArrow
        :rtype: DrawingArrow
        """
        return DrawingArrow(self.drawing_arrows.Add(i_head_point_x, i_head_point_y, i_tail_point_x, i_tail_point_y))

    def item(self, i_index: int) -> DrawingArrow:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(long iIndex) As DrawingArrow
                | 
                |     Returns a drawing arrow using its index from the DrawingArrows
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing arrow to retrieve from the collection of
                |             drawing arrows. As a numerics, this index is the rank of the drawing arrow in
                |             the collection. The index of the first drawing arrow in the collection is 1,
                |             and the index of the last drawing arrow is Count. 
                | 
                |     Returns:
                |         The retrieved drawing view 
                |     Example:
                |         This example retrieves in ThisDrawingArrow the second drawing arrow, in
                |         the drawing view collection of the active view in the active sheet, in the
                |         active document supposed to be a drawing document.
                | 
                |          Dim MyView  As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          Dim ThisDrawingArrow As DrawingArrow
                |          Set ThisDrawingArrow = MyView.Arrows.Item(2)

        :param int i_index:
        :return: DrawingArrow
        :rtype: DrawingArrow
        """
        return DrawingArrow(self.drawing_arrows.Item(i_index))

    def remove(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(long iIndex)
                | 
                |     Removes a drawing arrow from the DrawingArrows collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing arrow to remove from the collection of
                |             drawing arrows. As a numerics, this index is the rank of the drawing arrow in
                |             the collection. The index of the first drawing arrow in the collection is 1,
                |             and the index of the last drawing arrow is Count. 
                | 
                |     Example:
                |         The following example removes the third drawing arrow in the drawing
                |         arrow collection of the active view of the active document, supposed to be a
                |         drawing document.
                | 
                |          Dim MyView As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          MyView.DrawingArrows.Remove(3)

        :param int i_index:
        :return: None
        :rtype: None
        """
        return self.drawing_arrows.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingArrow:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingArrow(self.drawing_arrows.item(n + 1))

    def __iter__(self) -> Iterator[DrawingArrow]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'DrawingArrows(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator
from typing import TYPE_CHECKING
from typing import Optional

from pywintypes import com_error

from pycatia.exception_handling import CATIAApplicationException
from pycatia.knowledge_interfaces.bool_param import BoolParam
from pycatia.knowledge_interfaces.dimension import Dimension
from pycatia.knowledge_interfaces.int_param import IntParam
from pycatia.knowledge_interfaces.list_parameter import ListParameter
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.knowledge_interfaces.str_param import StrParam
from pycatia.knowledge_interfaces.units import Units
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant
from pycatia.types.general import any_parameter

if TYPE_CHECKING:
    from pycatia.knowledge_interfaces.parameter_set import ParameterSet


class Parameters(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Parameters
                | 
                | Represents the Parameters collection of the part or the
                | product.
                | The following example shows how to retrieve it:
                | 
                | 	Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim parameterList As Parameters
                |   Set parameterList = part1.Part.Parameters

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Parameter)
        self.parameters = com_object

    @property
    def root_parameter_set(self) -> 'ParameterSet':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property RootParameterSet() As ParameterSet (Read Only)
                | 
                |     Returns the root parameter set of a document. If it doesn't exist, it is
                |     created.

        :return: ParameterSet
        :rtype: ParameterSet
        """
        from pycatia.knowledge_interfaces.parameter_set import ParameterSet
        return ParameterSet(self.parameters.RootParameterSet)

    @property
    def units(self) -> Units:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Units() As Units (Read Only)
                | 
                |     Returns the collection of units.

        :return: Units
        :rtype: Units
        """

        return Units(self.parameters.Units)

    def all_parameters(self):
        """
        :return: list(Parameter())
        """

        parameters = []

        if self.has_parameters():
            for i in range(self.parameters.Count):
                para = Parameter(self.parameters.Item(i + 1))
                parameters.append(para)

        return parameters

    def create_boolean(self, i_name: str, i_value: bool):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateBoolean(CATBSTR iName,
                | boolean iValue) As BoolParam
                | 
                |     Creates a boolean parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the checked boolean parameter and adds it to the
                |         newly created part:
                | 
                |         Dim CATDocs As Documents
                |          Set CATDocs = CATIA.Documents
                |          Dim part1 As Document
                |          Set part1   = CATDocs.Add("CATPart")
                |          Dim chk As BooleanParam
                |           Set chk = part1.Part.Parameters.CreateBoolean ("checked", False)

        :param str i_name:
        :param bool i_value:
        :return: BoolParam
        :rtype: BoolParam
        """
        return BoolParam(self.parameters.CreateBoolean(i_name, i_value))

    def create_dimension(self, i_name: str, i_magnitude: str, i_value: float) -> Dimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateDimension(CATBSTR iName,
                | CATBSTR iMagnitude,
                | double iValue) As Dimension
                | 
                |     Creates a user dimension and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The dimension name 
                |         iMagnitude
                |             The dimension magnitude. Units are those of the IS system. Valid
                |             magnitudes are:
                | 
                |                 "LENGTH": the unit is the meter.
                |                 "ANGLE": the unit is the radian. 
                | 
                |             The 
                | 
                |         Dimension object provides the Dimension.ValuateFromString method with
                |         which you may express the value in any unit for a given dimension (see the
                |         example below). 
                |     iValue
                |         The dimension value provided as a real number 
                |     Example:
                |         This example creates a LENGTH dimension and adds it to the newly
                |         created part. The initial value is expressed in meters. The new value is
                |         expressed in millimeters.
                | 
                |          Dim depth As Dimension
                |          Set depth = parameters.CreateDimension("depth", "LENGTH", 20)
                |          depth.ValuateFromString("300mm");

        :param str i_name:
        :param str i_magnitude:
        :param float i_value:
        :return: Dimension
        :rtype: Dimension
        """
        return Dimension(self.parameters.CreateDimension(i_name, i_magnitude, i_value))

    def create_integer(self, i_name: str, i_value: int) -> IntParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateInteger(CATBSTR iName,
                | long iValue) As IntParam
                | 
                |     Creates an integer parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the RevisionNumber integer parameter and adds it
                |         to the newly created part:
                | 
                |         Dim CATDocs As Documents
                |          Set CATDocs = CATIA.Documents
                |          Dim part1 As Document
                |          Set part1   = CATDocs.Add("CATPart")
                |          Dim revision As IntParam
                |           Set revision = part1.Part.Parameters.CreateInteger ("RevisionRumber", 17)

        :param str i_name:
        :param int i_value:
        :return: IntParam
        :rtype: IntParam
        """
        return IntParam(self.parameters.CreateInteger(i_name, i_value))

    def create_list(self, i_name: str) -> ListParameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateList(CATBSTR iName) As ListParameter
                | 
                |     Creates a list parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                | 
                |     Example:
                |         This example creates the ListName list parameter and adds it to the
                |         newly created part:
                | 
                |           Set CATDocs = CATIA.Documents
                |           Set part1   = CATDocs.Add("CATPart")
                |           Set list1 = part1.Part.Parameters.CreateList ("ListName")

        :param str i_name:
        :return: ListParameter
        :rtype: ListParameter
        """
        return ListParameter(self.parameters.CreateList(i_name))

    def create_real(self, i_name: str, i_value: float) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateReal(CATBSTR iName,
                | double iValue) As RealParam
                | 
                |     Creates a real parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the ReliabilityRate real parameter and adds it to
                |         the newly created part:
                | 
                |         Dim CATDocs As Documents
                |          Set CATDocs = CATIA.Documents
                |          Dim part1 As Document
                |          Set part1   = CATDocs.Add("CATPart")
                |          Dim rate As RealParam
                |           Set rate = part1.Part.Parameters.CreateReal ("ReliabilityRate", 2.5 )

        :param str i_name:
        :param float i_value:
        :return: RealParam
        :rtype: RealParam
        """
        return RealParam(self.parameters.CreateReal(i_name, i_value))

    def create_set_of_parameters(self, i_father: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub CreateSetOfParameters(AnyObject iFather)
                | 
                |     Creates a set of parameters and appends it to argument iFather.

        :param AnyObject i_father:
        :return: None
        :rtype: None
        """
        return self.parameters.CreateSetOfParameters(i_father.com_object)

    def create_string(self, i_name: str, i_value: str) -> StrParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateString(CATBSTR iName,
                | CATBSTR iValue) As StrParam
                | 
                |     Creates a string parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the responsible string parameter and adds it to
                |         the newly created part:
                | 
                |           Set CATDocs = CATIA.Documents
                |           Set part1   = CATDocs.Add("CATPart")
                |           Set density = part1.Part.Parameters.CreateString ("responsible", "The Boss")

        :param str i_name:
        :param str i_value:
        :return: StrParam
        :rtype: StrParam
        """
        return StrParam(self.parameters.CreateString(i_name, i_value))

    def get_name_to_use_in_relation(self, i_object: AnyObject) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetNameToUseInRelation(AnyObject iObject) As CATBSTR
                | 
                |     Returns a correct name of a feature to use it in a relation.

        :param AnyObject i_object:
        :return: str
        :rtype: str
        """
        return self.parameters.GetNameToUseInRelation(i_object.com_object)

    def has_parameters(self):
        """
        :return: bool
        """
        if self.parameters.Count > 0:
            return True

        return False

    def is_parameter(self, index: cat_variant):
        """
        :param cat_variant index: parameter name or parameter number
        :return: bool
        :rtype: bool
        """
        try:
            if self.parameters.Item(index):
                return True
        except com_error:
            return False

    def item(self, index: cat_variant) -> any_parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help
                | Item
                | o Func Item(    CATVariant    iIndex) As Parameter
                |
                | Retrieves a parameter  using its index or its name from the from the
                | Parameters collection.
                | Parameters:
                | iIndex
                |    The index or the name of the parameter to retrieve from
                |    the collection of parameters.
                |    As a numeric, this index is the rank of the parameter
                |    in the collection.
                |    The index of the first parameter in the collection is 1, and
                |    the index of the last parameter is Count.
                |    As a string, it is the name you assigned to the parameter using
                |    the
                |
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property or when
                |  creating the parameter.
                | Examples:
                | This example retrieves the last parameter in the parameters
                | collection:
                |
                | Set lastParameter = parameters.Item(parameters.Count)


        :param cat_variant index:
        :return: any_parameter
        :rtype: any_parameter
        """

        p: any_parameter

        if not self.is_parameter(index):
            raise CATIAApplicationException(f'Could not find parameter name "{index}".')

        if isinstance(self.parameters.Item(index).value, bool):
            p = BoolParam(self.parameters.Item(index))

        elif isinstance(self.parameters.Item(index).value, int):
            p = IntParam(self.parameters.Item(index))

        elif isinstance(self.parameters.Item(index).value, str):
            p = StrParam(self.parameters.Item(index))

        elif isinstance(self.parameters.Item(index).value, float):
            p = RealParam(self.parameters.Item(index))

        else:

            raise CATIAApplicationException(f'Could not assign parameter name "{index}".')

        return p

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a parameter from the Parameters collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the parameter to remove from the
                |             collection of parameters. As a numerics, this index is the rank of the
                |             parameter in the collection. The index of the first parameter in the collection
                |             is 1, and the index of the last parameter is Count. As a string, it is the name
                |             you assigned to the parameter using the 
                | 
                |         AnyObject.Name property or when creating the parameter.
                |         
                |     Example:
                |         This example removes the "depth" parameter from the parameters
                |         collection.
                | 
                |          parameters.Remove("depth")

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.parameters.Remove(i_index)

    def sub_list(self, i_object: AnyObject, i_recursively: bool) -> 'Parameters':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func SubList(AnyObject iObject,
                | boolean iRecursively) As Parameters
                | 
                |     Returns a sub-collection of parameters aggregated to an
                |     object.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object used to filter the whole parameter collection to get the
                |             resulting sub-collection. 
                |         iRecursively
                |             A flag to specify if children parameters are to be searched for in
                |             the returned collection 
                |         Example:
                |             This example shows how to retrieve a collection of parameters that
                |             are associated to a Pad.
                | 
                |              Dim Parameters1 As Parameters
                |              Set Parameters1 = CATIA.ActiveDocument.Part.Parameters gets the collection of parameters
                |                  in the part
                |              Dim Body0 As AnyObject
                |              Set Body0 = CATIA.ActiveDocument.Part.Bodies.Item  ( "MechanicalTool.1" ) 
                |              Dim Pad1 As AnyObject
                |              Set Pad1 = Body0.Shapes.Item  ( "Pad.1" ) gets the pad Pad.1
                |              Dim Parameters2 As Parameters
                |              Set Parameters2 = Parameters1.SubList(Pad1,TRUE) gets the collection of parameters that
                |                  are under the pad Pad.1

        :param AnyObject i_object:
        :param bool i_recursively:
        :return: Parameters
        :rtype: Parameters
        """
        return Parameters(self.parameters.SubList(i_object.com_object, i_recursively))

    def __getitem__(self, n: int) -> Parameter:
        if (n + 1) > self.count:
            raise StopIteration

        return Parameter(self.parameters.item(n + 1))

    def __iter__(self) -> Iterator[Parameter]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Parameters(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.system_interfaces.cat_base_dispatch import CATBaseDispatch


class DrawingTextProperties(CATBaseDispatch):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 DrawingTextProperties
                | 
                | Represents the properties of a drawing text in a drawing view.
                | 
                | This interface is obtained from CATIADrawingText or CATIADrawingWelding
                | interface. Update method must be called after text properties modification to
                | refresh the visualization.
    
    """

    def __init__(self, com_object):
        super().__init__()
        self.drawing_text_properties = com_object

    @property
    def anchor_point(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AnchorPoint() As CatTextAnchorPosition
                | 
                |     Returns or sets the anchor point of the drawing text.
                | 
                |     Example:
                |         This example sets the AnchorPoint of the MyText drawing text to the
                |         right
                | 
                |          MyText.AnchorPoint = catRight

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.AnchorPoint

    @anchor_point.setter
    def anchor_point(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.AnchorPoint = value

    @property
    def blanking(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Blanking() As CatBlankingMode
                | 
                |     Returns or sets the blanking mode of the drawing text.
                | 
                |     Example:
                |         This example sets the blanking mode type of MyText drawing text to
                |         active on geom
                | 
                |          MyText.Blanking = catBlankingOnGeom

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Blanking

    @blanking.setter
    def blanking(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Blanking = value

    @property
    def bold(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Bold() As long
                | 
                |     Returns or sets the drawing text font bold property.
                |     True if the drawing text is bold formatted.
                | 
                |     Example:
                |         This example get the parameter bold on MyText drawing
                |         text.
                | 
                |          oVal = MyText.Bold

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Bold

    @bold.setter
    def bold(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Bold = value

    @property
    def color(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Color() As long
                | 
                |     Returns or sets the color of the drawing text.
                | 
                |     Example:
                |         This example sets the Color type of the MyText drawing text to
                |         red
                | 
                |          redCol  =-16776961 'Encoded RGBA color within long integer (R=255 G=0 
                |          B=0   A=255)
                |          MyText.Color = redCol

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Color

    @color.setter
    def color(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Color = value

    @property
    def font_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property FontName() As CATBSTR
                | 
                |     Returns or sets the font name of the drawing text.
                | 
                |     Example:
                |         This example sets the MyText drawing text font as Courrier 10
                |         BT.
                | 
                |          MyText.SetFontName("Courrier 10 BT")

        :return: str
        :rtype: str
        """

        return self.drawing_text_properties.FontName

    @font_name.setter
    def font_name(self, value: str):
        """
        :param str value:
        """

        self.drawing_text_properties.FontName = value

    @property
    def font_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property FontSize() As double
                | 
                |     Returns or sets the font size of the drawing text.
                | 
                |     Example:
                |         This example sets the MyText drawing text font size to
                |         3.5.
                | 
                |          iFontSize = 3.5
                |          MyText.SetFontSize 0, 0, iFontSize

        :return: float
        :rtype: float
        """

        return self.drawing_text_properties.FontSize

    @font_size.setter
    def font_size(self, value: float):
        """
        :param float value:
        """

        self.drawing_text_properties.FontSize = value

    @property
    def frame_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property FrameType() As CatTextFrameType
                | 
                |     Returns or sets the frame type of the drawing text.
                | 
                |     Example:
                |         This example sets the frame type of the MyText drawing text to an
                |         ellipse
                | 
                |          MyText.FrameType = catEllipse

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.FrameType

    @frame_type.setter
    def frame_type(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.FrameType = value

    @property
    def italic(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Italic() As long
                | 
                |     Returns or sets the drawing text font italic property.
                |     True if the drawing text is formatted as italic.
                | 
                |     Example:
                |         This example set the parameter Italic on MyText drawing
                |         text.
                | 
                |          MyText.Italic = 1

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Italic

    @italic.setter
    def italic(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Italic = value

    @property
    def justification(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Justification() As CatJustification
                | 
                |     Returns or sets the drawing text font justification
                |     property.
                |     True if the drawing text font is justified.
                | 
                |     Example:
                |         This example sets the Justification type of the MyText drawing text to
                |         the right
                | 
                |          MyText.Justification = catRight

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Justification

    @justification.setter
    def justification(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Justification = value

    @property
    def kerning(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Kerning() As long
                | 
                |     Font kerning property.
                |     True if the drawing text font is formatted as kerning
                | 
                |     Example:
                |         This example set the parameter kerning on MyText drawing
                |         text.
                | 
                |          MyText.Kerning = 1

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Kerning

    @kerning.setter
    def kerning(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Kerning = value

    @property
    def mirror(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Mirror() As CatTextFlipMode
                | 
                |     Returns or sets the mirroring of the drawing text.
                | 
                |     Example:
                |         This example sets the Mirror type of the MyText drawing text to no
                |         flip
                | 
                |          MyText.Mirror = catTextNoFlip

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Mirror

    @mirror.setter
    def mirror(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Mirror = value

    @property
    def overline(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Overline() As long
                | 
                |     Returns or sets the drawing text font overline property.
                |     True if the drawing text is overlined.
                | 
                |     Example:
                |         This example get the parameter Overline on MyText drawing
                |         text.
                | 
                |          oval = MyText.Overline()

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Overline

    @overline.setter
    def overline(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Overline = value

    @property
    def strike_thru(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property StrikeThru() As long
                | 
                |     Returns or sets the drawing text font strikethrough
                |     property.
                |     True if the drawing text font is striked through.
                | 
                |     Example:
                |         This example set the parameter StrikeThru on MyText drawing
                |         text.
                | 
                |          MyText.StrikeThru = 1

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.StrikeThru

    @strike_thru.setter
    def strike_thru(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.StrikeThru = value

    @property
    def subscript(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Subscript() As long
                | 
                |     Returns or sets the drawing text font subscript property.
                |     True if the drawing text font is formatted as subscript.
                | 
                |     Example:
                |         This example set the parameter Subscript on MyText drawing
                |         text.
                | 
                |          MyText.Subscript = 1

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Subscript

    @subscript.setter
    def subscript(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Subscript = value

    @property
    def superscript(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Superscript() As long
                | 
                |     Returns or sets the drawing text font superscript
                |     property.
                |     True if the drawing text font is formatted as superscript.
                | 
                |     Example:
                |         This example set the parameter Superscript on MyText drawing
                |         text.
                | 
                |          MyText.Superscript = 1

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Superscript

    @superscript.setter
    def superscript(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Superscript = value

    @property
    def underline(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Underline() As long
                | 
                |     Returns or sets the drawing text font underline property.
                |     True if the drawing text is underlined.
                | 
                |     Example:
                |         This example get the parameter bold on MyText drawing
                |         text.
                | 
                |          oval = MyText.Underline

        :return: int
        :rtype: int
        """

        return self.drawing_text_properties.Underline

    @underline.setter
    def underline(self, value: int):
        """
        :param int value:
        """

        self.drawing_text_properties.Underline = value

    def activate_frame(self, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ActivateFrame(CatTextFrameType iType)
                | 
                |     Activates the text frame of the drawing text.
                | 
                |     Parameters:
                | 
                |         iType
                |             The text frame type 
                | 
                |     Example:
                |         This example add a rectangle frame to MyText drawing
                |         text.
                | 
                |          CatTextFrameType itype = catRectangle
                |          MyText.ActivateFrame itype
                |          
                | 
                | Example:
                | 
                |       This example remove the frame to MyText drawing text.
                |      
                | 
                |      CatTextFrameType itype = catNone
                |      MyText.ActivateFrame itype

        :param int i_type:
        :return: None
        :rtype: None
        """
        return self.drawing_text_properties.ActivateFrame(i_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'activate_frame'
        # # vba_code = """
        # # Public Function activate_frame(drawing_text_properties)
        # #     Dim iType (2)
        # #     drawing_text_properties.ActivateFrame iType
        # #     activate_frame = iType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Update()
                | 
                |     Update the properties of the drawing text. 
                | 
                | Example:
                |     This example update the properties to MyText drawing text.
                | 
                |      MyText.Update 
                |      
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :return: None
        :rtype: None
        """
        return self.drawing_text_properties.Update()

    def __repr__(self):
        return f'DrawingTextProperties()'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PageSetup(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PageSetup
                | 
                | Represents the page setup.
                | The page setup is the object that stores data which defines how your documents
                | and images are actually printed on paper. This data includes namely the paper
                | size, the orientation, the bottom, top, right, and left margins, the zoom
                | factor, the banner, and the printing quality.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.page_setup = com_object

    def __repr__(self):
        return f'PageSetup(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.tps_interfaces.annotation import Annotation
    from pycatia.tps_interfaces.annotation_2 import Annotation2


class AssociatedRefFrame(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AssociatedRefFrame
                | 
                | Interface dedicated to manage Datum Reference Frame associated to a
                | TPS.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.associated_ref_frame = com_object

    @property
    def reference_frame(self) -> 'Annotation':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceFrame() As Annotation (Read Only)
                | 
                |     Retrieves the Datum Reference Frame associated to a TPS. Deprecated method:
                |     ReferenceFrame method is replaced by ReferenceFrame2 has.

        :return: Annotation
        :rtype: Annotation
        """

        from pycatia.tps_interfaces.annotation import Annotation
        return Annotation(self.associated_ref_frame.ReferenceFrame)

    @property
    def reference_frame_2(self) -> 'Annotation2':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceFrame2() As Annotation2 (Read Only)
                | 
                |     Retrieves the Datum Reference Frame associated to a TPS.

        :return: Annotation2
        :rtype: Annotation2
        """

        from pycatia.tps_interfaces.annotation_2 import Annotation2
        return Annotation2(self.associated_ref_frame.ReferenceFrame2)

    def __repr__(self):
        return f'AssociatedRefFrame(name="{self.name}")'
